@@ -28,8 +28,20 @@ from .proto.cosmos.tx.v1beta1 import (
 
 
 class Client:
-    def __init__(self, grpc_endpoint: str):
-        channel = grpc.insecure_channel(grpc_endpoint)
+    def __init__(
+        self,
+        grpc_endpoint: str,
+        insecure: bool = False,
+        credentials: grpc.ChannelCredentials = None,
+    ):
+        channel = (
+            grpc.insecure_channel(grpc_endpoint)
+            if insecure
+            else grpc.secure_channel(
+                grpc_endpoint,
+                credentials or grpc.ssl_channel_credentials(),
+            )
+        )
         self.stubOracle = oracle_query_grpc.QueryStub(channel)
         self.stubCosmosTendermint = tendermint_query_grpc.ServiceStub(channel)
         self.stubAuth = auth_query_grpc.QueryStub(channel)
@@ -45,7 +57,7 @@ class Client:
     def get_request_by_id(self, id: int) -> oracle_query.QueryRequestResponse:
         return self.stubOracle.Request(oracle_query.QueryRequestRequest(request_id=id))
 
-    def get_reporters(self, validator: str) -> oracle_type.ReportersPerValidator.reporters:
+    def get_reporters(self, validator: str) -> oracle_query.QueryReportersResponse.reporter:
         return self.stubOracle.Reporters(oracle_query.QueryReportersRequest(validator_address=validator)).reporter
 
     def get_latest_block(self) -> tendermint_query.GetLatestBlockResponse:
